// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

enum Format {
  /// JSON i18 file format.
  json(['json']),

  /// YAML i18 file format.
  yaml(['yaml', 'yml']),

  /// ARB i18 file format.
  arb(['arb']);

  const Format(this.extensions);

  final List<String> extensions;

  /// Returns the [Format] that matches the given [ext].
  static Format? fromExtension(String ext) {
    for (final format in Format.values) {
      if (format.extensions.contains(ext)) {
        return format;
      }
    }

    return null;
  }

  /// Returns the [Format] that matches the given [path].
  static Format? extensionOf(String path) =>
      fromExtension(path.split('.').last);
}
