// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:wyatt_architecture/wyatt_architecture.dart';
import 'package:wyatt_i18n/src/domain/data_sources/i18n_data_source.dart';
import 'package:wyatt_i18n/src/domain/entities/i18n.dart';
import 'package:wyatt_i18n/src/domain/repositories/i18n_repository.dart';
import 'package:wyatt_type_utils/wyatt_type_utils.dart';

class I18RepositoryImpl extends I18nRepository {
  const I18RepositoryImpl({
    required this.dataSource,
  }) : super();

  final I18nDataSource dataSource;

  @override
  FutureOrResult<I18n> load(String locale) async =>
      await Result.tryCatchAsync<I18n, AppException, AppException>(
        () async {
          final content = await dataSource.load(locale);
          // TODO: Parse the content into a Map<String, dynamic> and return it.

          return I18n(locale: locale, 
          unparsedData: content,
          data: {},);
        },
        (error) => error,
      );
}
